@@ -24,8 +24,7 @@ Usage::
 from datetime import datetime
 from typing import Generic, Iterator, Sequence, TypeVar, Union
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import ApplicationStateType, JobRunStateType
 from .type_defs import (
@@ -47,7 +46,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListApplicationsPaginator(Boto3Paginator):
+class ListApplicationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-serverless.html#EMRServerless.Paginator.ListApplications)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_serverless/paginators/#listapplicationspaginator)
@@ -65,7 +64,7 @@ class ListApplicationsPaginator(Boto3Paginator):
         """
 
 
-class ListJobRunsPaginator(Boto3Paginator):
+class ListJobRunsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr-serverless.html#EMRServerless.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_serverless/paginators/#listjobrunspaginator)
