@@ -34,6 +34,7 @@ __all__ = (
     "ConfigurationTypeDef",
     "DeleteApplicationRequestRequestTypeDef",
     "GetApplicationRequestRequestTypeDef",
+    "GetDashboardForJobRunRequestRequestTypeDef",
     "GetJobRunRequestRequestTypeDef",
     "HiveTypeDef",
     "WorkerResourceConfigTypeDef",
@@ -52,6 +53,7 @@ __all__ = (
     "UntagResourceRequestRequestTypeDef",
     "CancelJobRunResponseTypeDef",
     "CreateApplicationResponseTypeDef",
+    "GetDashboardForJobRunResponseTypeDef",
     "ListApplicationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "StartJobRunResponseTypeDef",
@@ -201,6 +203,14 @@ GetApplicationRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetDashboardForJobRunRequestRequestTypeDef = TypedDict(
+    "GetDashboardForJobRunRequestRequestTypeDef",
+    {
+        "applicationId": str,
+        "jobRunId": str,
+    },
+)
+
 GetJobRunRequestRequestTypeDef = TypedDict(
     "GetJobRunRequestRequestTypeDef",
     {
@@ -429,6 +439,14 @@ CreateApplicationResponseTypeDef = TypedDict(
     },
 )
 
+GetDashboardForJobRunResponseTypeDef = TypedDict(
+    "GetDashboardForJobRunResponseTypeDef",
+    {
+        "url": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListApplicationsResponseTypeDef = TypedDict(
     "ListApplicationsResponseTypeDef",
     {
